==> rikulo_commons-1.1.2%2B2.tar.gz: README.md <==
#Rikulo Commons


[Rikulo Commons](http://rikulo.org) is a collection of common reusable Dart classes and utilities.

* [Home](http://rikulo.org)
* [Repository](https://github.com/rikulo/commons)
* [Documentation](http://docs.rikulo.org)
* [API Reference](http://api.rikulo.org/commons/latest)
* [Discussion](http://stackoverflow.com/questions/tagged/rikulo)
* [Issues](https://github.com/rikulo/commons/issues)

Rikulo Commons is distributed under an Apache 2.0 License.

[![Build Status](https://drone.io/github.com/rikulo/commons/status.png)](https://drone.io/github.com/rikulo/commons/latest)

##Install

Add this to your `pubspec.yaml` (or create it):

    dependencies:
      rikulo_commmons:

Then run the [Pub Package Manager](http://pub.dartlang.org/doc) (comes with the Dart SDK):

    pub install

##Run on Client and/or Server

<table border="1" width="100%">
  <tr>
    <td>Library</td>
    <td>Run on Server</td>
    <td>Run on Client</td>
  </tr>
  <tr>
    <td><code>async.dart</code></td>
    <td>Yes</td>
    <td>Yes</td>
  </tr>
  <tr>
    <td><code>browser.dart</code></td>
    <td>Yes</td>
    <td>Yes</td>
  </tr>
  <tr>
    <td><code>html.dart</code></td>
    <td>No</td>
    <td>Yes</td>
  </tr>
  <tr>
    <td><code>io.dart</code></td>
    <td>Yes</td>
    <td>No</td>
  </tr>
  <tr>
    <td><code>logging.dart</code></td>
    <td>Yes</td>
    <td>Yes</td>
  </tr>
  <tr>
    <td><code>mirrors.dart</code></td>
    <td>Yes</td>
    <td>Yes</td>
  </tr>
  <tr>
    <td><code>util.dart</code></td>
    <td>Yes</td>
    <td>Yes</td>
  </tr>
</table>

##Notes to Contributors

###Fork Rikulo Commons

If you'd like to contribute back to the core, you can [fork this repository](https://help.github.com/articles/fork-a-repo) and send us a pull request, when it is ready.

Please be aware that one of Rikulo's design goals is to keep the sphere of API as neat and consistency as possible. Strong enhancement always demands greater consensus.

If you are new to Git or GitHub, please read [this guide](https://help.github.com/) first.

##Who Uses

* [Quire](https://quire.io) - a simple, collaborative, multi-level task management tool.

==> rikulo_commons-2.1.1%2B2.tar.gz: README.md <==
# Rikulo Commons


[Rikulo Commons](http://rikulo.org) is a collection of common reusable Dart classes and utilities.

* [Home](http://rikulo.org)
* [Repository](https://github.com/rikulo/commons)
* [Documentation](http://docs.rikulo.org)
* [API Reference](http://www.dartdocs.org/documentation/rikulo_commons/2.1.1)
* [Discussion](http://stackoverflow.com/questions/tagged/rikulo)
* [Issues](https://github.com/rikulo/commons/issues)

Rikulo Commons is distributed under an Apache 2.0 License.

[![Build Status](https://drone.io/github.com/rikulo/commons/status.png)](https://drone.io/github.com/rikulo/commons/latest)

## Install

Add this to your `pubspec.yaml` (or create it):

    dependencies:
      rikulo_commmons:

## Run on Client and/or Server

<table border="1" width="100%">
  <tr>
    <td>Library</td>
    <td>Run on Server</td>
    <td>Run on Client</td>
  </tr>
  <tr>
    <td><code>async.dart</code></td>
    <td>Yes</td>
    <td>Yes</td>
  </tr>
  <tr>
    <td><code>browser.dart</code></td>
    <td>Yes</td>
    <td>Yes</td>
  </tr>
  <tr>
    <td><code>io.dart</code></td>
    <td>Yes</td>
    <td>No</td>
  </tr>
  <tr>
    <td><code>logging.dart</code></td>
    <td>Yes</td>
    <td>Yes</td>
  </tr>
  <tr>
    <td><code>mirrors.dart</code></td>
    <td>Yes</td>
    <td>Yes</td>
  </tr>
  <tr>
    <td><code>util.dart</code></td>
    <td>Yes</td>
    <td>Yes</td>
  </tr>
</table>

## Notes to Contributors

### Fork Rikulo Commons

If you'd like to contribute back to the core, you can [fork this repository](https://help.github.com/articles/fork-a-repo) and send us a pull request, when it is ready.

Please be aware that one of Rikulo's design goals is to keep the sphere of API as neat and consistency as possible. Strong enhancement always demands greater consensus.

If you are new to Git or GitHub, please read [this guide](https://help.github.com/) first.

## Who Uses

* [Quire](https://quire.io) - a simple, collaborative, multi-level task management tool.
